@@ -36,7 +36,8 @@
 #' @importFrom DiagrammeR grViz
 #' @export plot_life_cycle
 plot_life_cycle <- function(matA, stages, title = NULL, shape = "egg",
-                            fontsize = 10, nodefontsize = 12, edgecol = "grey") {
+                            fontsize = 10, nodefontsize = 12,
+                            edgecol = "grey") {
   # Identify stages
   if (missing(stages) && is.null(dimnames(matA))) {
     stages <- seq_len(ncol(matA))
@@ -47,8 +48,11 @@ plot_life_cycle <- function(matA, stages, title = NULL, shape = "egg",
       dimnames(matA)[[1]],
       dimnames(matA)[[2]]
     )) {
-      message(strwrap(prefix = " ", initial = "", "Dimension names of 'matA' are not identical
-                for rows and columns. Using row names."))
+      message(strwrap(
+        prefix = " ", initial = "",
+        "Dimension names of 'matA' are not identical
+      for rows and columns. Using row names."
+      ))
     }
   }
 
