@@ -1,6 +1,6 @@
 test_that("plot_life_cycle works correctly", {
   mat_a <- mat_u + mat_f
-  stages <- letters[1:nrow(mat_a)]
+  stages <- letters[seq_len(nrow(mat_a))]
 
   p1 <- plot_life_cycle(mat_a)
   p2 <- plot_life_cycle(mat_a, stages = stages)
@@ -14,8 +14,8 @@ test_that("plot_life_cycle works correctly", {
 
 test_that("plot_life_cycle warns and fails gracefully", {
   mat_a <- mat_u + mat_f
-  colnames(mat_a) <- paste0("A", 1:nrow(mat_a))
-  rownames(mat_a) <- paste0("B", 1:nrow(mat_a))
+  colnames(mat_a) <- paste0("A", seq_len(nrow(mat_a)))
+  rownames(mat_a) <- paste0("B", seq_len(nrow(mat_a)))
   # make rownames different from colnames
   stages <- dimnames(mat_a)[[1]]
 
