@@ -22,10 +22,10 @@ test_that("vr_vec functions work correctly", {
   expect_length(grow1, 4)
 
   grow2 <- vr_vec_growth(U1, posU = matrix(TRUE, nrow = 4, ncol = 4))
-  expect_true(!is.na(grow2[1]))
+  expect_false(is.na(grow2[1]))
 
   grow3 <- vr_vec_growth(U1, surv_only_na = FALSE)
-  expect_true(!is.na(grow3[1]))
+  expect_false(is.na(grow3[1]))
 
   shri1 <- vr_vec_shrinkage(U1)
   expect_type(shri1, "double")
@@ -39,17 +39,17 @@ test_that("vr_vec functions work correctly", {
   expect_length(stas1, 4)
 
   stas2 <- vr_vec_stasis(U1, posU = matrix(TRUE, nrow = 4, ncol = 4))
-  expect_equal(stas2[1], 0)
+  expect_identical(stas2[1], 0)
 
   dent1 <- vr_vec_dorm_enter(U1, dorm_stages = 4)
   expect_type(dent1, "double")
   expect_length(dent1, 4)
-  expect_true(!is.na(dent1[3]))
+  expect_false(is.na(dent1[3]))
 
   dexi1 <- vr_vec_dorm_exit(U1, dorm_stages = 4)
   expect_type(dexi1, "double")
   expect_length(dexi1, 4)
-  expect_true(!is.na(dexi1[4]))
+  expect_false(is.na(dexi1[4]))
 
 
   R1 <- rbind(
@@ -78,7 +78,7 @@ test_that("vr_vec functions work correctly", {
   )
 
   fecu3 <- vr_vec_reproduction(U2, R1)
-  expect_equal(fecu3[4], sum(R1[, 4]))
+  expect_identical(fecu3[4], sum(R1[, 4]))
 })
 
 
